@@ -31,7 +31,7 @@ import re
 from collections import OrderedDict, defaultdict
 from dataclasses import dataclass
 from datetime import date
-from typing import TYPE_CHECKING, Callable, Iterable
+from typing import TYPE_CHECKING, Iterable
 
 from jinja2 import (
     BaseLoader,
@@ -43,6 +43,8 @@ from jinja2 import (
 
 from commitizen import out
 from commitizen.bump import normalize_tag
+from commitizen.cz.base import ChangelogReleaseHook
+from commitizen.defaults import get_tag_regexes
 from commitizen.exceptions import InvalidConfigurationError, NoCommitsFoundError
 from commitizen.git import GitCommit, GitTag
 from commitizen.version_schemes import (
@@ -52,6 +54,7 @@ from commitizen.version_schemes import (
 )
 
 if TYPE_CHECKING:
+    from commitizen.cz.base import MessageBuilderHook
     from commitizen.version_schemes import VersionScheme
 
 
@@ -91,16 +94,21 @@ def tag_included_in_changelog(
     return True
 
 
-def get_version_tags(scheme: type[BaseVersion], tags: list[GitTag]) -> list[GitTag]:
+def get_version_tags(
+    scheme: type[BaseVersion], tags: list[GitTag], tag_format: str
+) -> list[GitTag]:
     valid_tags: list[GitTag] = []
+    TAG_FORMAT_REGEXS = get_tag_regexes(scheme.parser.pattern)
+    tag_format_regex = tag_format
+    for pattern, regex in TAG_FORMAT_REGEXS.items():
+        tag_format_regex = tag_format_regex.replace(pattern, regex)
     for tag in tags:
-        try:
-            scheme(tag.name)
-        except InvalidVersion:
-            out.warn(f"InvalidVersion {tag}")
-        else:
+        if re.match(tag_format_regex, tag.name):
             valid_tags.append(tag)
-
+        else:
+            out.warn(
+                f"InvalidVersion {tag.name} doesn't match configured tag format {tag_format}"
+            )
     return valid_tags
 
 
@@ -111,7 +119,8 @@ def generate_tree_from_commits(
     changelog_pattern: str,
     unreleased_version: str | None = None,
     change_type_map: dict[str, str] | None = None,
-    changelog_message_builder_hook: Callable | None = None,
+    changelog_message_builder_hook: MessageBuilderHook | None = None,
+    changelog_release_hook: ChangelogReleaseHook | None = None,
     merge_prerelease: bool = False,
     scheme: VersionScheme = DEFAULT_SCHEME,
 ) -> Iterable[dict]:
@@ -142,11 +151,14 @@ def generate_tree_from_commits(
             commit_tag, used_tags, merge_prerelease, scheme=scheme
         ):
             used_tags.append(commit_tag)
-            yield {
+            release = {
                 "version": current_tag_name,
                 "date": current_tag_date,
                 "changes": changes,
             }
+            if changelog_release_hook:
+                release = changelog_release_hook(release, commit_tag)
+            yield release
             current_tag_name = commit_tag.name
             current_tag_date = commit_tag.date
             changes = defaultdict(list)
@@ -156,37 +168,58 @@ def generate_tree_from_commits(
             continue
 
         # Process subject from commit message
-        message = map_pat.match(commit.message)
-        if message:
-            parsed_message: dict = message.groupdict()
-
-            if changelog_message_builder_hook:
-                parsed_message = changelog_message_builder_hook(parsed_message, commit)
-            if parsed_message:
-                change_type = parsed_message.pop("change_type", None)
-                if change_type_map:
-                    change_type = change_type_map.get(change_type, change_type)
-                changes[change_type].append(parsed_message)
+        if message := map_pat.match(commit.message):
+            process_commit_message(
+                changelog_message_builder_hook,
+                message,
+                commit,
+                changes,
+                change_type_map,
+            )
 
         # Process body from commit message
         body_parts = commit.body.split("\n\n")
         for body_part in body_parts:
-            message_body = body_map_pat.match(body_part)
-            if not message_body:
-                continue
-            parsed_message_body: dict = message_body.groupdict()
-
-            if changelog_message_builder_hook:
-                parsed_message_body = changelog_message_builder_hook(
-                    parsed_message_body, commit
+            if message := body_map_pat.match(body_part):
+                process_commit_message(
+                    changelog_message_builder_hook,
+                    message,
+                    commit,
+                    changes,
+                    change_type_map,
                 )
-            if parsed_message_body:
-                change_type = parsed_message_body.pop("change_type", None)
-                if change_type_map:
-                    change_type = change_type_map.get(change_type, change_type)
-                changes[change_type].append(parsed_message_body)
 
-    yield {"version": current_tag_name, "date": current_tag_date, "changes": changes}
+    release = {
+        "version": current_tag_name,
+        "date": current_tag_date,
+        "changes": changes,
+    }
+    if changelog_release_hook:
+        release = changelog_release_hook(release, commit_tag)
+    yield release
+
+
+def process_commit_message(
+    hook: MessageBuilderHook | None,
+    parsed: re.Match[str],
+    commit: GitCommit,
+    changes: dict[str | None, list],
+    change_type_map: dict[str, str] | None = None,
+):
+    message: dict = {
+        "sha1": commit.rev,
+        "author": commit.author,
+        "author_email": commit.author_email,
+        **parsed.groupdict(),
+    }
+
+    if processed := hook(message, commit) if hook else message:
+        messages = [processed] if isinstance(processed, dict) else processed
+        for msg in messages:
+            change_type = msg.pop("change_type", None)
+            if change_type_map:
+                change_type = change_type_map.get(change_type, change_type)
+            changes[change_type].append(msg)
 
 
 def order_changelog_tree(tree: Iterable, change_type_order: list[str]) -> Iterable:
@@ -324,7 +357,6 @@ def get_oldest_and_newest_rev(
         oldest, newest = version.split("..")
     except ValueError:
         newest = version
-
     newest_tag = normalize_tag(newest, tag_format=tag_format, scheme=scheme)
 
     oldest_tag = None
